@@ -1,16 +1,14 @@
-# -*- coding: utf-8 -*-
 """File wrappers for use as exchange data between views and responses."""
-from __future__ import absolute_import
 from io import BytesIO
-from six.moves.urllib.parse import urlparse
+from urllib.parse import urlparse
 
 from django.core.files.base import File
 from django.utils.encoding import force_bytes
 
-import requests
-
 from django_downloadview.io import BytesIteratorIO
 
+import requests
+
 
 class StorageFile(File):
     """A file in a Django storage.
@@ -19,6 +17,7 @@ class StorageFile(File):
     but unrelated to model instance.
 
     """
+
     def __init__(self, storage, name, file=None):
         """Constructor.
 
@@ -35,8 +34,8 @@ class StorageFile(File):
 
     def _get_file(self):
         """Getter for :py:attr:``file`` property."""
-        if not hasattr(self, '_file') or self._file is None:
-            self._file = self.storage.open(self.name, 'rb')
+        if not hasattr(self, "_file") or self._file is None:
+            self._file = self.storage.open(self.name, "rb")
         return self._file
 
     def _set_file(self, file):
@@ -50,7 +49,7 @@ class StorageFile(File):
     #: Required by django.core.files.utils.FileProxy.
     file = property(_get_file, _set_file, _del_file)
 
-    def open(self, mode='rb'):
+    def open(self, mode="rb"):
         """Retrieves the specified file from storage and return open() result.
 
         Proxy to self.storage.open(self.name, mode).
@@ -122,7 +121,10 @@ class StorageFile(File):
         Proxy to self.storage.accessed_time(self.name).
 
         """
-        return self.storage.accessed(self.name)
+        try:
+            return self.storage.get_accessed_time(self.name)
+        except AttributeError:
+            return self.storage.accessed_time(self.name)
 
     @property
     def created_time(self):
@@ -131,7 +133,10 @@ class StorageFile(File):
         Proxy to self.storage.created_time(self.name).
 
         """
-        return self.storage.created_time(self.name)
+        try:
+            return self.storage.get_created_time(self.name)
+        except AttributeError:
+            return self.storage.created_time(self.name)
 
     @property
     def modified_time(self):
@@ -140,12 +145,16 @@ class StorageFile(File):
         Proxy to self.storage.modified_time(self.name).
 
         """
-        return self.storage.modified_time(self.name)
+        try:
+            return self.storage.get_modified_time(self.name)
+        except AttributeError:
+            return self.storage.modified_time(self.name)
 
 
 class VirtualFile(File):
     """Wrapper for files that live in memory."""
-    def __init__(self, file=None, name=u'', url='', size=None):
+
+    def __init__(self, file=None, name="", url="", size=None):
         """Constructor.
 
         file:
@@ -196,7 +205,7 @@ class VirtualFile(File):
 
                 # If this is the end of a line, yield
                 # otherwise, wait for the next round
-                if line[-1] in ('\n', '\r'):
+                if line[-1] in ("\n", "\r"):
                     yield line
                 else:
                     buffer_ = line
@@ -215,19 +224,19 @@ class HTTPFile(File):
     Always sets "stream=True" in requests kwargs.
 
     """
-    def __init__(self, request_factory=requests.get, url='', name=u'',
-                 **kwargs):
+
+    def __init__(self, request_factory=requests.get, url="", name="", **kwargs):
         self.request_factory = request_factory
         self.url = url
         if name is None:
             parts = urlparse(url)
             if parts.path:  # Name from path.
-                self.name = parts.path.strip('/').rsplit('/', 1)[-1]
+                self.name = parts.path.strip("/").rsplit("/", 1)[-1]
             else:  # Name from domain.
                 self.name = parts.netloc
         else:
             self.name = name
-        kwargs['stream'] = True
+        kwargs["stream"] = True
         self.request_kwargs = kwargs
 
     @property
@@ -235,8 +244,7 @@ class HTTPFile(File):
         try:
             return self._request
         except AttributeError:
-            self._request = self.request_factory(self.url,
-                                                 **self.request_kwargs)
+            self._request = self.request_factory(self.url, **self.request_kwargs)
             return self._request
 
     @property
@@ -255,9 +263,9 @@ class HTTPFile(File):
         Reads response's "content-length" header.
 
         """
-        return self.request.headers['Content-Length']
+        return self.request.headers["Content-Length"]
 
     @property
     def content_type(self):
         """Return content type of the file (from original response)."""
-        return self.request.headers['Content-Type']
+        return self.request.headers["Content-Type"]
